print.VarCorr.glmmTMB: Printing The Variance and Correlation Parameters of a
Description
Printing The Variance and Correlation Parameters of a glmmTMBUsage
# S3 method for VarCorr.glmmTMB
print(x, digits = max(3, getOption("digits") - 2),
comp = "Std.Dev.", formatter = format, ...)Arguments
digits
number of significant digits to use.
comp
a string specifying the component to format and print.
...
optional further arguments, passed the next print method.