set_simcodes: helper function to modify simulation settings for random effects
Description
This modifies the TMB object in place (beware!)
Ultimately this will allow terms to be a vector of term names,
with a matching val vector to specify the behaviour for each term
Usage
set_simcodes(g, val = "zero", terms = "ALL")
Arguments
- g
a TMB object
- val
a legal setting for sim codes ("zero", "random", or "fix")
- terms
which terms to apply this to