Learn R Programming

glmmTMB (version 1.1.15.2)

summary.glmmTMB: summary for glmmTMB fits

Description

summary for glmmTMB fits

Usage

# S3 method for glmmTMB
summary(
  object,
  sandwich = FALSE,
  ddf = c("asymptotic", "kenward-roger", "satterthwaite"),
  cluster = getGroups(object),
  ...
)

Arguments

object

a fitted glmmTMB object

sandwich

use the sandwich estimator for the variance-covariance matrix? (this only works for ML fits, but not for REML fits)

ddf

denominator degrees-of-freedom calculation. Default "asymptotic" gives standard Z-statistics (i.e., 'infinite' denominator df); "kenward-roger" uses the Kenward-Roger approximation (see dof_KR), which requires a REML fit (an error is thrown otherwise) and a family with an estimated dispersion parameter (an error is thrown for families such as binomial or poisson that lack one); "satterthwaite" uses a Satterthwaite approximation, with no such restrictions. For families other than gaussian, both approximations are allowed but emit a warning, because their performance (and theoretical justification) for GLMMs is poorly understood

cluster

grouping factor for the sandwich estimator, only used if sandwich==TRUE.

...

unused, for method compatibility

Details

For the ordinal family, the returned object has a thresholds element (a matrix of threshold estimates, delta-method standard errors, and z values), printed as “Threshold coefficients”; the thresholds are estimated internally via a softmax parameterization, so the corresponding rows of vcov(., full = TRUE) are not on the threshold scale