Learn R Programming

glmmTMB (version 1.1.15.2)

weights.glmmTMB: Extract weights from a glmmTMB object

Description

Extract weights from a glmmTMB object

Usage

# S3 method for glmmTMB
weights(object, type = "prior", ...)

Arguments

object

a fitted glmmTMB object

type

weights type

...

additional arguments (not used; for methods compatibility)

Details

Returns the prior weights used in fitting, i.e. weights specified in the weights argument. For binomial-type families fit with a two-column matrix response (cbind(successes, failures)), the total number of trials is included as well (multiplied by the weights argument, if specified), matching the behaviour of glm and glmer. Since glmmTMB does not fit models via iteratively weighted least squares, working weights (see weights.glm) are unavailable.