Methods have been written that allow glmmTMB objects to be used with
several downstream packages that enable different forms of inference.
In particular,
car::Anova constructs type-II and type-III Anova tables
for the fixed effect parameters of the conditional model (this might work with the
fixed effects of the zero-inflation or dispersion models, but has not been tested)
the effects package computes graphical tabular effect displays
(again, for the fixed effects of the conditional component)
the emmeans package computes estimated marginal means (aka least-squares means)
for the fixed effects of the conditional component
Anova.glmmTMB(
mod,
type = c("II", "III", 2, 3),
test.statistic = c("Chisq", "F"),
component = "cond",
vcov. = vcov(mod)[[component]],
singular.ok,
...
)Effect.glmmTMB(focal.predictors, mod, ...)
recover_data.glmmTMB(object, ...)
emm_basis.glmmTMB(object, trms, xlev, grid, component = "cond", ...)
a glmmTMB model
type of test, "II", "III", 2, or 3. Roman numerals are equivalent to the corresponding Arabic numerals. See Anova for details.
unused: only valid choice is "Chisq" (i.e., Wald chi-squared test)
which component of the model to compute emmeans for (conditional ("cond"), zero-inflation ("zi"), or dispersion ("disp"))
variance-covariance matrix (usually extracted automatically)
OK to do ANOVA with singular models (unused) ?
Additional parameters that may be supported by the method.
a character vector of one or more predictors in the model in any order.
a glmmTMB model
The terms component of object (typically with the
response deleted, e.g. via delete.response
Named list of factor levels (excluding ones coerced to factors in the model formula)
A data.frame (provided by ref_grid) containing the
predictor settings needed in the reference grid
While the examples below are disabled for earlier versions of
R, they may still work; it may be necessary to refer to private
versions of methods, e.g. glmmTMB:::Anova.glmmTMB(model, ...).