anova method for glmmTMB fits, comparing two or more nested models
# S3 method for glmmTMB
anova(
object,
...,
model.names = NULL,
ddf = c("asymptotic", "kenward-roger", "satterthwaite")
)a fitted glmmTMB model
additional glmmTMB model(s) to compare against object
optional vector of names for the models being compared
denominator degrees-of-freedom calculation, as in summary.glmmTMB.
The default "asymptotic" gives a likelihood ratio test; any other value
gives an F-ratio test, with the numerator df equal to the difference in the
number of fixed-effect parameters between each pair of nested models and the
denominator df computed via the Kenward-Roger or Satterthwaite approximation
(see dof_KR, dof_satt)